.. _physics-docs:

=======
Physics
=======

.. automodule:: sympy.physics

**Contents**

.. toctree::
   :titlesonly:

   ../../../modules/physics/hydrogen.rst
   ../../../modules/physics/matrices.rst
   ../../../modules/physics/paulialgebra.rst
   ../../../modules/physics/qho_1d.rst
   ../../../modules/physics/sho.rst
   ../../../modules/physics/secondquant.rst
   ../../../modules/physics/wigner.rst
   ../../../modules/physics/units/index.rst
   ../../../modules/physics/hep/index.rst
   ../../../modules/physics/vector/index.rst
   ../../../modules/physics/mechanics/index.rst
   ../../../modules/physics/quantum/index.rst
   ../../../modules/physics/optics/index.rst
   ../../../modules/physics/control/index.rst
   ../../../modules/physics/continuum_mechanics/index.rst
